Module: MemoizeUntil::TimePatch
- Defined in:
- lib/memoize_until/time_patch.rb
Instance Method Summary collapse
-
#week ⇒ Object
returns number representing the nth week of the month.
Instance Method Details
#week ⇒ Object
returns number representing the nth week of the month
7 8 9 |
# File 'lib/memoize_until/time_patch.rb', line 7 def week day / 7 end |