Class: MemoizeUntil
- Inherits:
-
Object
- Object
- MemoizeUntil
- Defined in:
- lib/memoize_until/base.rb,
lib/memoize_until/store.rb,
lib/memoize_until/railtie.rb,
lib/memoize_until/extensions.rb,
lib/memoize_until/time_patch.rb
Defined Under Namespace
Modules: TimePatch Classes: NotImplementedError, NullObject, Railtie, Store
Class Method Summary collapse
-
.add_to(kind, key) ⇒ Object
Adds a purpose at runtime for the specified kind.
-
.clear_now_for(kind, key) ⇒ Object
clears previously memoized value for "now" for the given key only clears memory in the process that this code runs on.
Class Method Details
.add_to(kind, key) ⇒ Object
Adds a purpose at runtime for the specified kind.
44 45 46 |
# File 'lib/memoize_until/base.rb', line 44 def self.add_to(kind, key) TYPE_FACTORY[kind].add(key) end |
.clear_now_for(kind, key) ⇒ Object
clears previously memoized value for "now" for the given key only clears memory in the process that this code runs on. added for supporting custom scripts / test cases
59 60 61 |
# File 'lib/memoize_until/base.rb', line 59 def self.clear_now_for(kind, key) TYPE_FACTORY[kind].clear_now(key) end |